Original code:

 - http://code.activestate.com/recipes/577686-bloom-filter/
 - Author: Sundar Srinivasan

Forked into SVN Repo:

 - http://stromberg.dnsalias.org/svn/bloom-filter/trunk/
 - Author: Daniel Richard Stromberg

Forked to GitHub, renamed to `bloom_filter`:

 - https://github.com/hiway/python-bloom-filter
 - Author: Harshad Sharma
